==> uke-admin-web-scaffold-1.2.1.tgz: package/template-engine/for-report/records-template.js <==
/* eslint-disable consistent-return */
/**
 * 组件名    通用报表布局
 * 作者      Alex
 * 日期      2018-07-30
 */
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import React, { Component } from 'react';
import { GetFloatLen, ToggleBasicFloatLen, HasValue, DebounceClass, Call } from 'basic-helper';
// import { getDefPagin } from '../../utils/pagination-helper';
import { getScreenInfo } from '../../utils/dom';
import { Pagination, CardTable, Loading, Button, Toast, Table, ConditionGenerator, getElementOffset, DropdownMenu, Switch } from '../../ui-refs';
var delayExec = new DebounceClass();
var offsetBottom = 70;
var autoRefreshOptions = {
    0: '关闭',
    2: '自动',
    15: '15秒',
    30: '30秒',
    45: '45秒',
    60: '60秒',
};
var ReportTemplate = /** @class */ (function (_super) {
    __extends(ReportTemplate, _super);
    function ReportTemplate(props) {
        var _this = _super.call(this, props) || this;
        _this.defaultPagin = {};
        _this.audioMask = true;
        _this.refreshTime = 15;
        _this.setSoundUrl = function (nextUrl) {
            _this.soundUrl = nextUrl;
            var soundSplit = nextUrl.split('.');
            _this.soundType = soundSplit[soundSplit.length - 1];
        };
        _this.setAutoRefreshTimer = function () {
            if (!_this.props.needAutoRefresh)
                return;
            if (_this.refreshTime === 0) {
                _this.clearAutoRefreshTimer();
            }
            else {
                _this.clearAutoRefreshTimer();
                _this.refreshTimer = setTimeout(function () {
                    _this.handleQueryData(null, _this.setAutoRefreshTimer);
                }, _this.refreshTime * 1000);
            }
        };
        _this.clearAutoRefreshTimer = function () {
            if (_this.refreshTimer) {
                clearInterval(_this.refreshTimer);
                _this.refreshTimer = null;
            }
        };
        _this.changeRefreshTime = function (nextTime) {
            _this.refreshTime = nextTime;
            _this.setAutoRefreshTimer();
        };
        _this.clearCheckeds = function () {
            _this._tableRef.clearCheckeds();
        };
        _this.handleRes = function (_a) {
            var resDesc = _a.resDesc, hasErr = _a.hasErr;
            hasErr && _this.toast.show(resDesc, hasErr ? 'error' : 'success');
        };
        _this.whenMountedQuery = function (data) {
            if (_this.didMountQueried)
                return;
            delayExec.exec(function () {
                _this.handleQueryData(data);
                _this.didMountQueried = true;
            }, 100);
        };
        _this.refreshData = function () {
            _this.props.onQueryData(_this.getQueryData());
        };
        /**
         * 获取查询条件
         * @param {object} conditionData 查询条件
         * @param {object} nextPagin 下一个分页数据
         * @param {boolean} [merge=true] 是否把 conditionData 合并到 this.conditionHelper.value 之中
         * @memberof ReportTemplate
         */
        _this.getQueryData = function (conditionData, nextPagin, merge) {
            if (merge === void 0) { merge = true; }
            var _conditionData = merge
                ? Object.assign({}, _this.conditionHelper.value, conditionData)
                : conditionData || _this.conditionHelper.value;
            return {
                nextPagin: nextPagin || _this.props.pagingInfo,
                conditionData: _conditionData,
                selectedItems: _this.checkedItems
            };
        };
        _this.setTableContainerHeight = function () {
            var tableContainer = _this.tableContainerRef;
            if (_this.__setHeight || !tableContainer)
                return;
            delayExec.exec(function () {
                if (_this.__unmount)
                    return;
                var tableContainerOffsetTop = getElementOffset(tableContainer).offsetTop;
                /** 高度调整策略，如果该页面被隐藏，则在下一次 update 的时候更新此高度，保证高度的正确性 */
                if (tableContainerOffsetTop === 0) {
                    _this.__setHeight = false;
                    return;
                }
                var tableContainerHeight = getScreenInfo().screenHeight - tableContainerOffsetTop - offsetBottom;
                _this.setState({
                    tableHeight: tableContainerHeight
                });
                _this.__setHeight = true;
            }, 100);
        };
        _this.restoreBasicFloatLen = function () {
            if (GetFloatLen() == 0) {
                ToggleBasicFloatLen();
            }
        };
        /**
         * 小数点开关
         * 在管理中心的时候可以用，但是关闭管理中心后必须设置回去
         */
        _this.toggleFloat = function () {
            var isDisplay = ToggleBasicFloatLen();
            _this.setState({
                displayFloat: isDisplay
            });
        };
        _this.handleQueryData = function (val, callback) {
            /** TODO: 观察，点击查询的时候，默认返回第一页 */
            var data = Object.assign({}, _this.getQueryData(val, _this.defaultPagin), {
                onGetResInfo: _this.handleRes, callback: callback
            });
            _this.props.onQueryData(data);
        };
        _this.handleChangeCondition = function (val, ref) {
            var _a = _this.props, autoQuery = _a.autoQuery, onChangeCondition = _a.onChangeCondition;
            delayExec.exec(function () {
                Call(onChangeCondition, val, ref);
            }, 200);
            if (!autoQuery || !HasValue(val[ref]))
                return;
            delayExec.exec(function () {
                _this.handleQueryData(val);
                Call(onChangeCondition, val, ref);
            }, 200);
        };
        _this.saveConditionRef = function (e) {
            if (e) {
                _this.conditionHelper = e;
                if (_this.props.didMountQuery)
                    _this.whenMountedQuery(e.value);
            }
        };
        _this.handlePagin = function (nextPagin) {
            _this.props.onQueryData({
                nextPagin: nextPagin,
                conditionData: _this.conditionHelper.value,
            });
        };
        _this.toggleCondition = function (isExpand) {
            _this.setState({
                expandCon: isExpand
            });
            _this.__setHeight = false;
            setTimeout(function () { return _this.setTableContainerHeight(); }, 200);
        };
        _this.saveWarnRef = function (e) { _this.soundRef = e; };
        _this.saveToast = function (toast) { _this.toast = toast; };
        _this.renderAutoRefresh = function () {
            return (React.createElement("span", { className: "mr10 layout a-i-c" },
                React.createElement("span", { className: "mr10" }),
                React.createElement(DropdownMenu, { needAction: false, position: "right", defaultValue: _this.refreshTime, values: autoRefreshOptions, onChange: _this.changeRefreshTime }),
                React.createElement("span", { className: "ms10" }, "\u58F0\u97F3"),
                React.createElement(Switch, { onChange: function (val) {
                        _this.audioMask = val;
                        if (!_this.soundUrl)
                            return console.warn('请先通过 ReportTemplateRef.setSoundUrl 设置声音的 url');
                        if (!val)
                            _this.soundRef.pause();
                    }, defaultChecked: _this.audioMask }),
                React.createElement("audio", { id: "soundRef", ref: _this.saveWarnRef }, _this.soundUrl && React.createElement("source", { src: _this.soundUrl, type: "audio/" + _this.soundType }))));
        };
        _this.renderActionBtns = function (actionBtns) {
            return actionBtns.map(function (btn) {
                var text = btn.text, action = btn.action, _a = btn.color, color = _a === void 0 ? 'default' : _a;
                return (React.createElement(Button, { key: text, text: _this.props.$T(text), color: color, className: "mr10", onClick: action }));
            });
        };
        _this.renderToggleBtn = function () {
            var $T = _this.props.$T;
            var expandCon = _this.state.expandCon;
            return (React.createElement(Button, { icon: expandCon ? "angle-double-up" : "angle-double-down", color: "default", className: "mr10", onClick: function (e) { return _this.toggleCondition(!expandCon); } }, $T('高级搜索')));
        };
        _this.state = {
            displayFloat: GetFloatLen() != 0,
            tableHeight: props.height || 200,
            expandCon: props.defaultExpandCon
        };
        var soundUrl = props.soundUrl;
        if (soundUrl)
            _this.setSoundUrl(soundUrl);
        return _this;
    }
    ReportTemplate.prototype.componentDidMount = function () {
        this.defaultPagin = this.props.pagingInfo;
        this.setAutoRefreshTimer();
    };
    ReportTemplate.prototype.componentDidUpdate = function () {
        this.setTableContainerHeight();
    };
    ReportTemplate.prototype.componentWillUnmount = function () {
        this.restoreBasicFloatLen();
        this.__unmount = true;
        this.didMountQueried = false;
        this.clearAutoRefreshTimer();
    };
    ReportTemplate.prototype.shouldComponentUpdate = function (nextProps, nextState) {
        var _a = this.props, _b = _a.needAutoRefresh, needAutoRefresh = _b === void 0 ? false : _b, records = _a.records;
        if (needAutoRefresh && this.audioMask && nextProps.records != records) {
            this.soundRef.play();
        }
        return true;
    };
    ReportTemplate.prototype.render = function () {
        var _this = this;
        var _a = this.props, _b = _a.records, records = _b === void 0 ? [] : _b, pagingInfo = _a.pagingInfo, querying = _a.querying, children = _a.children, template = _a.template, needCount = _a.needCount, showCondition = _a.showCondition, needCheck = _a.needCheck, whenCheckAction = _a.whenCheckAction, needPaging = _a.needPaging, loadingCondition = _a.loadingCondition, height = _a.height, actionBtns = _a.actionBtns, infoMapper = _a.infoMapper, conditionOptions = _a.conditionOptions, $T = _a.$T, keyMapper = _a.keyMapper, columns = _a.columns, hideFloatable = _a.hideFloatable, calculateHeight = _a.calculateHeight, sortIgnores = _a.sortIgnores, needInnerSort = _a.needInnerSort, needClearBtn = _a.needClearBtn, needAutoRefresh = _a.needAutoRefresh, propsForTable = _a.propsForTable;
        var _columns = columns || keyMapper;
        var hasConditionOptions = conditionOptions.length > 0;
        var _c = this.state, displayFloat = _c.displayFloat, tableHeight = _c.tableHeight, expandCon = _c.expandCon;
        var _tableH = height || tableHeight;
        switch (template) {
            case 'CardTable':
                this.templateDOM = (React.createElement(React.Fragment, null,
                    React.createElement(Loading, { loading: !!querying, inrow: true }),
                    React.createElement(CardTable, { columns: _columns, records: records })));
                break;
            case 'Table':
            default:
                var _propsForTable = __assign(__assign({}, propsForTable), { needCheck: needCheck, columns: _columns, whenCheckAction: whenCheckAction,
                    sortIgnores: sortIgnores,
                    needInnerSort: needInnerSort,
                    needCount: needCount,
                    records: records, height: _tableH });
                this.templateDOM = (React.createElement("div", { className: "table-container", ref: function (e) {
                        if (!calculateHeight || height || !e || records.length === 0)
                            return;
                        _this.tableContainerRef = e;
                        _this.setTableContainerHeight();
                    } },
                    React.createElement("div", { className: "table-scroll" },
                        React.createElement(Loading, { loading: !!querying, inrow: true }),
                        React.createElement(Table, __assign({}, _propsForTable, { onChange: function (emitVal, config) {
                                switch (config.type) {
                                    case 'selector':
                                        // 为 selector 修改 conditionHelper 的值，做缓存
                                        _this.conditionHelper.changeValues(emitVal);
                                        break;
                                }
                            }, ref: function (e) { _this._tableRef = e; }, onCheck: function (nextItems) {
                                _this.checkedItems = nextItems;
                            } })))));
                break;
        }
        if (!this.templateDOM) {
            return (React.createElement("span", null, $T('没有对应的模板')));
        }
        var pagingDOM = needPaging && pagingInfo ? (React.createElement(Pagination, { pagingInfo: pagingInfo, infoMapper: infoMapper, onPagin: this.handlePagin })) : null;
        var conditionHelper = !loadingCondition && (React.createElement(ConditionGenerator, { ref: this.saveConditionRef, onChange: this.handleChangeCondition, conditionConfig: conditionOptions }));
        var actionArea = (React.createElement("div", { className: "action-area layout" },
            React.createElement(Button, { text: $T('查询'), type: "submit", className: "mr10", loading: querying, onClick: function (e) {
                    _this.handleQueryData();
                } }),
            needClearBtn && hasConditionOptions && (React.createElement(Button, { text: $T('清空'), color: "red", className: "mr10", onClick: function (e) {
                    _this.conditionHelper.clearValue();
                } })),
            !hideFloatable && (React.createElement(Button, { text: $T(displayFloat ? '隐藏小数点' : '显示小数点'), className: "default mr10", onClick: function (e) { return _this.toggleFloat(); } })),
            actionBtns && this.renderActionBtns(actionBtns),
            this.renderToggleBtn(),
            needAutoRefresh && this.renderAutoRefresh()));
        return (React.createElement("div", { className: "report-table-layout" },
            React.createElement(Toast, { ref: this.saveToast }),
            React.createElement("div", { 
                // ref={(e) => {
                //   if (e) {
                //     console.log(e.offsetHeight);
                //   }
                // }}
                className: "report-fix-con " + (showCondition ? '' : ' hide') + " " + (expandCon ? 'expand' : 'collapse') },
                React.createElement("form", { onSubmit: function (e) {
                        e.preventDefault();
                    } },
                    conditionHelper,
                    actionArea),
                children),
            React.createElement("div", null, pagingDOM),
            this.templateDOM));
    };
    ReportTemplate.defaultProps = {
        autoQuery: false,
        defaultExpandCon: false,
        didMountQuery: true,
        needAutoRefresh: false,
        needClearBtn: true,
        hideFloatable: true,
        needCount: false,
        calculateHeight: true,
        querying: true,
        isMobile: false,
        needCheck: false,
        loadingCondition: false,
        showCondition: true,
        needPaging: true,
        template: 'Table',
        conditionOptions: [],
        $T: function (str) { return str; },
        resDesc: '',
    };
    return ReportTemplate;
}(Component));
export default ReportTemplate;

==> uke-admin-web-scaffold-1.2.4.tgz: package/template-engine/for-report/records-template.js <==
/* eslint-disable consistent-return */
/**
 * 组件名    通用报表布局
 * 作者      Alex
 * 日期      2018-07-30
 */
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import React, { Component } from 'react';
import { GetFloatLen, ToggleBasicFloatLen, HasValue, DebounceClass, Call } from 'basic-helper';
// import { getDefPagin } from '../../utils/pagination-helper';
import { getScreenInfo } from '../../utils/dom';
import { Pagination, CardTable, Loading, Button, Toast, Table, ConditionGenerator, getElementOffset, DropdownMenu, Switch } from '../../ui-refs';
var delayExec = new DebounceClass();
var offsetBottom = 70;
var autoRefreshOptions = {
    0: '关闭',
    2: '自动',
    15: '15秒',
    30: '30秒',
    45: '45秒',
    60: '60秒',
};
var ReportTemplate = /** @class */ (function (_super) {
    __extends(ReportTemplate, _super);
    function ReportTemplate(props) {
        var _this = _super.call(this, props) || this;
        _this.defaultPagin = {};
        _this.audioMask = true;
        _this.refreshTime = 15;
        _this.setSoundUrl = function (nextUrl) {
            _this.soundUrl = nextUrl;
            var soundSplit = nextUrl.split('.');
            _this.soundType = soundSplit[soundSplit.length - 1];
        };
        _this.setAutoRefreshTimer = function () {
            if (!_this.props.needAutoRefresh)
                return;
            if (_this.refreshTime === 0) {
                _this.clearAutoRefreshTimer();
            }
            else {
                _this.clearAutoRefreshTimer();
                _this.refreshTimer = setTimeout(function () {
                    _this.handleQueryData(null, _this.setAutoRefreshTimer);
                }, _this.refreshTime * 1000);
            }
        };
        _this.clearAutoRefreshTimer = function () {
            if (_this.refreshTimer) {
                clearInterval(_this.refreshTimer);
                _this.refreshTimer = null;
            }
        };
        _this.changeRefreshTime = function (nextTime) {
            _this.refreshTime = nextTime;
            _this.setAutoRefreshTimer();
        };
        _this.clearCheckeds = function () {
            _this._tableRef.clearCheckeds();
        };
        _this.handleRes = function (_a) {
            var resDesc = _a.resDesc, hasErr = _a.hasErr;
            hasErr && _this.toast.show(resDesc, hasErr ? 'error' : 'success');
        };
        _this.whenMountedQuery = function (data) {
            if (_this.didMountQueried)
                return;
            delayExec.exec(function () {
                _this.handleQueryData(data);
                _this.didMountQueried = true;
            }, 100);
        };
        _this.refreshData = function () {
            _this.props.onQueryData(_this.getQueryData());
        };
        /**
         * 获取查询条件
         * @param {object} conditionData 查询条件
         * @param {object} nextPagin 下一个分页数据
         * @param {boolean} [merge=true] 是否把 conditionData 合并到 this.conditionHelper.value 之中
         * @memberof ReportTemplate
         */
        _this.getQueryData = function (conditionData, nextPagin, merge) {
            if (merge === void 0) { merge = true; }
            var _conditionData = merge
                ? Object.assign({}, _this.conditionHelper.value, conditionData)
                : conditionData || _this.conditionHelper.value;
            return {
                nextPagin: nextPagin || _this.props.pagingInfo,
                conditionData: _conditionData,
                selectedItems: _this.checkedItems
            };
        };
        _this.setTableContainerHeight = function () {
            var tableContainer = _this.tableContainerRef;
            if (_this.__setHeight || !tableContainer)
                return;
            delayExec.exec(function () {
                if (_this.__unmount)
                    return;
                var tableContainerOffsetTop = getElementOffset(tableContainer).offsetTop;
                /** 高度调整策略，如果该页面被隐藏，则在下一次 update 的时候更新此高度，保证高度的正确性 */
                if (tableContainerOffsetTop === 0) {
                    _this.__setHeight = false;
                    return;
                }
                var tableContainerHeight = getScreenInfo().screenHeight - tableContainerOffsetTop - offsetBottom;
                _this.setState({
                    tableHeight: tableContainerHeight
                });
                _this.__setHeight = true;
            }, 100);
        };
        _this.restoreBasicFloatLen = function () {
            if (GetFloatLen() == 0) {
                ToggleBasicFloatLen();
            }
        };
        /**
         * 小数点开关
         * 在管理中心的时候可以用，但是关闭管理中心后必须设置回去
         */
        _this.toggleFloat = function () {
            var isDisplay = ToggleBasicFloatLen();
            _this.setState({
                displayFloat: isDisplay
            });
        };
        _this.handleQueryData = function (val, callback) {
            /** TODO: 观察，点击查询的时候，默认返回第一页 */
            var data = Object.assign({}, _this.getQueryData(val, _this.defaultPagin), {
                onGetResInfo: _this.handleRes, callback: callback
            });
            _this.props.onQueryData(data);
        };
        _this.handleChangeCondition = function (val, ref) {
            var _a = _this.props, autoQuery = _a.autoQuery, onChangeCondition = _a.onChangeCondition;
            delayExec.exec(function () {
                Call(onChangeCondition, val, ref);
            }, 200);
            if (!autoQuery || !HasValue(val[ref]))
                return;
            delayExec.exec(function () {
                _this.handleQueryData(val);
                Call(onChangeCondition, val, ref);
            }, 200);
        };
        _this.saveConditionRef = function (e) {
            if (e) {
                _this.conditionHelper = e;
                if (_this.props.didMountQuery)
                    _this.whenMountedQuery(e.value);
            }
        };
        _this.handlePagin = function (nextPagin) {
            _this.props.onQueryData({
                nextPagin: nextPagin,
                conditionData: _this.conditionHelper.value,
            });
        };
        _this.toggleCondition = function (isExpand) {
            _this.setState({
                expandCon: isExpand
            });
            _this.__setHeight = false;
            setTimeout(function () { return _this.setTableContainerHeight(); }, 200);
        };
        _this.saveWarnRef = function (e) { _this.soundRef = e; };
        _this.saveToast = function (toast) { _this.toast = toast; };
        _this.renderAutoRefresh = function () {
            return (React.createElement("span", { className: "mr10 layout a-i-c" },
                React.createElement("span", { className: "mr10" }),
                React.createElement(DropdownMenu, { needAction: false, position: "right", defaultValue: _this.refreshTime, values: autoRefreshOptions, onChange: _this.changeRefreshTime }),
                React.createElement("span", { className: "ms10" }, "\u58F0\u97F3"),
                React.createElement(Switch, { onChange: function (val) {
                        _this.audioMask = val;
                        if (!_this.soundUrl)
                            return console.warn('请先通过 ReportTemplateRef.setSoundUrl 设置声音的 url');
                        if (!val)
                            _this.soundRef.pause();
                    }, defaultChecked: _this.audioMask }),
                React.createElement("audio", { id: "soundRef", ref: _this.saveWarnRef }, _this.soundUrl && React.createElement("source", { src: _this.soundUrl, type: "audio/" + _this.soundType }))));
        };
        _this.renderActionBtns = function (actionBtns) {
            return actionBtns.map(function (btn) {
                var text = btn.text, action = btn.action, _a = btn.color, color = _a === void 0 ? 'default' : _a;
                return (React.createElement(Button, { key: text, text: _this.props.$T(text), color: color, className: "mr10", onClick: action }));
            });
        };
        _this.renderToggleBtn = function () {
            var $T = _this.props.$T;
            var expandCon = _this.state.expandCon;
            return (React.createElement(Button, { icon: expandCon ? "angle-double-up" : "angle-double-down", color: "default", className: "mr10", onClick: function (e) { return _this.toggleCondition(!expandCon); } }, $T('高级搜索')));
        };
        _this.state = {
            displayFloat: GetFloatLen() != 0,
            tableHeight: props.height || 200,
            expandCon: props.defaultExpandCon
        };
        var soundUrl = props.soundUrl;
        if (soundUrl)
            _this.setSoundUrl(soundUrl);
        return _this;
    }
    ReportTemplate.prototype.componentDidMount = function () {
        this.defaultPagin = this.props.pagingInfo;
        this.setAutoRefreshTimer();
    };
    ReportTemplate.prototype.componentDidUpdate = function () {
        this.setTableContainerHeight();
    };
    ReportTemplate.prototype.componentWillUnmount = function () {
        this.restoreBasicFloatLen();
        this.__unmount = true;
        this.didMountQueried = false;
        this.clearAutoRefreshTimer();
    };
    ReportTemplate.prototype.shouldComponentUpdate = function (nextProps, nextState) {
        var _a = this.props, _b = _a.needAutoRefresh, needAutoRefresh = _b === void 0 ? false : _b, records = _a.records;
        if (needAutoRefresh && this.audioMask && nextProps.records != records) {
            this.soundRef.play();
        }
        return true;
    };
    ReportTemplate.prototype.render = function () {
        var _this = this;
        var _a = this.props, _b = _a.records, records = _b === void 0 ? [] : _b, pagingInfo = _a.pagingInfo, querying = _a.querying, children = _a.children, template = _a.template, needCount = _a.needCount, showCondition = _a.showCondition, needCheck = _a.needCheck, whenCheckAction = _a.whenCheckAction, needPaging = _a.needPaging, loadingCondition = _a.loadingCondition, height = _a.height, actionBtns = _a.actionBtns, infoMapper = _a.infoMapper, conditionOptions = _a.conditionOptions, $T = _a.$T, keyMapper = _a.keyMapper, columns = _a.columns, hideFloatable = _a.hideFloatable, calculateHeight = _a.calculateHeight, sortIgnores = _a.sortIgnores, needInnerSort = _a.needInnerSort, needClearBtn = _a.needClearBtn, needAutoRefresh = _a.needAutoRefresh, propsForTable = _a.propsForTable;
        var _columns = columns || keyMapper;
        var hasConditionOptions = conditionOptions.length > 0;
        var _c = this.state, displayFloat = _c.displayFloat, tableHeight = _c.tableHeight, expandCon = _c.expandCon;
        var _tableH = height || tableHeight;
        switch (template) {
            case 'CardTable':
                this.templateDOM = (React.createElement(React.Fragment, null,
                    React.createElement(Loading, { loading: !!querying, inrow: true }),
                    React.createElement(CardTable, { columns: _columns, records: records })));
                break;
            case 'Table':
            default:
                var _propsForTable = __assign(__assign({}, propsForTable), { needCheck: needCheck, columns: _columns, whenCheckAction: whenCheckAction,
                    sortIgnores: sortIgnores,
                    needInnerSort: needInnerSort,
                    needCount: needCount,
                    records: records, height: _tableH });
                this.templateDOM = (React.createElement("div", { className: "table-container", ref: function (e) {
                        if (!calculateHeight || height || !e || records.length === 0)
                            return;
                        _this.tableContainerRef = e;
                        _this.setTableContainerHeight();
                    } },
                    React.createElement("div", { className: "table-scroll" },
                        React.createElement(Loading, { loading: !!querying, inrow: true }),
                        React.createElement(Table, __assign({}, _propsForTable, { onChange: function (emitVal, config) {
                                switch (config.type) {
                                    case 'selector':
                                        // 为 selector 修改 conditionHelper 的值，做缓存
                                        _this.conditionHelper.changeValues(emitVal);
                                        break;
                                }
                            }, ref: function (e) { _this._tableRef = e; }, onCheck: function (nextItems) {
                                _this.checkedItems = nextItems;
                            } })))));
                break;
        }
        if (!this.templateDOM) {
            return (React.createElement("span", null, $T('没有对应的模板')));
        }
        var pagingDOM = needPaging && pagingInfo ? (React.createElement(Pagination, { pagingInfo: pagingInfo, infoMapper: infoMapper, onPagin: this.handlePagin })) : null;
        var conditionHelper = !loadingCondition && (React.createElement(ConditionGenerator, { ref: this.saveConditionRef, onChange: this.handleChangeCondition, conditionConfig: conditionOptions }));
        var actionArea = (React.createElement("div", { className: "action-area layout" },
            React.createElement(Button, { text: $T('查询'), type: "submit", className: "mr10", loading: querying, onClick: function (e) {
                    _this.handleQueryData();
                } }),
            needClearBtn && hasConditionOptions && (React.createElement(Button, { text: $T('清空'), color: "red", className: "mr10", onClick: function (e) {
                    _this.conditionHelper.clearValue();
                } })),
            !hideFloatable && (React.createElement(Button, { text: $T(displayFloat ? '隐藏小数点' : '显示小数点'), color: "default", className: "mr10", onClick: function (e) { return _this.toggleFloat(); } })),
            actionBtns && this.renderActionBtns(actionBtns),
            this.renderToggleBtn(),
            needAutoRefresh && this.renderAutoRefresh()));
        return (React.createElement("div", { className: "report-table-layout" },
            React.createElement(Toast, { ref: this.saveToast }),
            React.createElement("div", { 
                // ref={(e) => {
                //   if (e) {
                //     console.log(e.offsetHeight);
                //   }
                // }}
                className: "report-fix-con " + (showCondition ? '' : ' hide') + " " + (expandCon ? 'expand' : 'collapse') },
                React.createElement("form", { onSubmit: function (e) {
                        e.preventDefault();
                    } },
                    conditionHelper,
                    actionArea),
                children),
            React.createElement("div", null, pagingDOM),
            this.templateDOM));
    };
    ReportTemplate.defaultProps = {
        autoQuery: false,
        defaultExpandCon: false,
        didMountQuery: true,
        needAutoRefresh: false,
        needClearBtn: true,
        hideFloatable: true,
        needCount: false,
        calculateHeight: true,
        querying: true,
        isMobile: false,
        needCheck: false,
        loadingCondition: false,
        showCondition: true,
        needPaging: true,
        template: 'Table',
        conditionOptions: [],
        $T: function (str) { return str; },
        resDesc: '',
    };
    return ReportTemplate;
}(Component));
export default ReportTemplate;
